==> devboard-0.5.0.tgz: package/lib/components/NamespaceList.js <==
var React = require('react');

var $ = React.createElement;

var routes = require('../routes');

var Link = require('./Link');

var styleGuide = require('../style-guide');
var style = {
  ul: {
    listStyleType: 'none',
    margin: 0,
    padding: '0 30px 50px',
    background: '#fff'
  },
  li: {
    padding: '0 10px 0 5px',
    borderBottom: styleGuide.cardBorder
  },
  link: {
    display: 'block',
    fontFamily: styleGuide.fontFamily,
    fontSize: '25px',
    lineHeight: styleGuide.bodyLineHeight,
    padding: '10px 0',
  },
  count: {
    display: 'inline-block',
    marginTop: '5px',
    fontSize: '18px',
    padding: '0 15px',
    float: 'right',
    borderRadius: '50px',
    background: '#999',
    color: 'white'
  }
};

var NamespaceList = React.createClass({
  displayName: 'DevboardNamespaceList',
  componentDidMount: function() {
    /* eslint-env browser */
    document.title = 'Devboard | Index';
  },
  render: function() {
    var catalog = this.props.catalog;
    var namespaces = Object.keys(catalog);
    namespaces.sort();
    return (
      $('ul', { style: style.ul },
        namespaces.map(function(namespace) {
          var num = catalog[namespace].length;

          return $('li', { key: namespace, style: style.li },
            $(Link, { href: routes.href(namespace), style: style.link },
              namespace,
              $('span', { style: style.count }, num)
            )
          );
        })
      )
    );
  }
});

module.exports = NamespaceList;

==> devboard-0.7.0.tgz: package/lib/components/NamespaceList.js <==
var React = require('react');

var $ = React.createElement;

var routes = require('../routes');

var Link = require('./Link');

var styleGuide = require('../style-guide');
var style = {
  ul: {
    listStyleType: 'none',
    margin: 0,
    padding: '0 30px 50px',
    background: '#fff'
  },
  li: {
    padding: '0 10px 0 5px',
    borderBottom: styleGuide.cardBorder
  },
  link: {
    display: 'block',
    fontFamily: styleGuide.fontFamily,
    fontSize: '25px',
    lineHeight: styleGuide.bodyLineHeight,
    padding: '10px 0',
  },
  count: {
    display: 'inline-block',
    marginTop: '5px',
    fontSize: '18px',
    padding: '0 15px',
    float: 'right',
    borderRadius: '50px',
    background: '#999',
    color: 'white'
  }
};

var NamespaceList = React.createClass({
  displayName: 'DevboardNamespaceList',
  componentDidMount: function() {
    /* eslint-env browser */
    document.title = 'Devboard | Index';
  },
  render: function() {
    var catalog = this.props.catalog;
    var namespaces = Object.keys(catalog);
    namespaces.sort();
    return (
      $('ul', { style: style.ul },
        namespaces.map(function(namespace) {
          var num = catalog[namespace].cards.length;

          return $('li', { key: namespace, style: style.li },
            $(Link, { href: routes.href(namespace), style: style.link },
              namespace,
              $('span', { style: style.count }, num)
            )
          );
        })
      )
    );
  }
});

module.exports = NamespaceList;
